vchartist
==========

vchartist is a modified version of [Chartist.js](https://gionkunz.github.io) for the sake of plugin development base on webpack.

When develop a chartist plugin, **Chartist** variable is often imported to provide some inner function. but in webpack, if you import chartist, it's code will be packed in the plugin's file. So i rewrite the chartist's **Base** Class. Provide **Chartist** variable as a default parameter when plugin function is called
```javascript
  if (this.options.plugins) {
    this.options.plugins.forEach(function (plugin) {
      if (plugin instanceof Array) {
        plugin[0](this, plugin[1], Chartist)
      } else {
        plugin(this, Chartist)
      }
    }.bind(this))
  }
```

vchartist also provide a vue plugin base on [vue-chartist](https://github.com/Yopadd/vue-chartist).

## install
  npm install vchartist

## Usage
In your HTML, add `<chartist>` tag. This tag take following attributes:

- **ratio** - `String`
class ratio of Chartist, see values on [Chartist web site](https://gionkunz.github.io/chartist-js/getting-started.html#as-simple-as-it-can-get)

- **type** - `String` (required)
the chart type, possible values :
  - `Line`
  - `Bar`
  - `Pie`

- **data** - `Object`
the data object like this
```javascript
  const data = {
    labels: ['A', 'B', 'C'],
    series: [
      [1, 3, 2],
      [4, 6, 5]
    ]
  }
```

- **options** - `Object`
the options object, see defaultOptions on [API Documentation](https://gionkunz.github.io/chartist-js/api-documentation.html)

- **event-handlers** - `Array`
a special array to use `chart.on(event, function)`
```javascript
  const eventHandlers = [{
    event: 'draw',
    fn() {
      //animation
    }
  }, {
    //an other event handler
  }]
```

- **responsive-options** - `Object`
the object for responsive options

### Example
```html
<chartist
  ratio="ct-major-second"
  type="Line"
  :data="chartData"
  :options="chartOptions">
</chartist>
```

>*Note: think about using the [dynamic props](http://vuejs.org/guide/components.html#Dynamic_Props) of Vuejs to bind easily your data or other.*

```javascript
  new Vue({
    el: '#app',
    data: {
      chartData: {
        labels: ['A', 'B', 'C'],
        series: [
          [1, 3, 2],
          [4, 6, 5]
        ]
      },
      chartOptions: {
        lineSmooth: false
      }
    }
  })
```
### Customize chart with no data
If chart datas are empty or not definite the plugin add `ct-nodata` class and write a message on the element.
Way, you can customize your element with CSS when you have no data to display. To choose your message use the options plugin :
```javascript
Vue.use(require('vchartist'),  {
  messageNoData: 'You have not enough data'
})
```
### License
[MIT](https://opensource.org/licenses/mit-license.php)
